/*

 Copyright (C) 2002 Andrew Brown

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or any
 later version.

 This program is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */
import jm.JMC;
import jm.music.data.*;
import jm.util.*;
import qt.QTPanel;
import javax.swing.*;
import qt.QTPlayer;
import qt.QTUtil;
import java.awt.*;
import java.awt.event.*;
import java.util.Vector;

/**
* This class creates a collage of similar parts, each
* of which may overlap and be rhythmicaly offset.
* The creation of parts is handled by the NPart class.
* This program requires the jMusic library, http://jmusic.ci.qut.edu.au/
* @author Andrew Brown 2002.
*/

public class NIAM implements JMC, ActionListener {
	private Score score = new Score();
	private JTabbedPane tabPane;
	private Button composeButton, saveButton, newPartButton, deletePartButton;
	private Vector nPartList = new Vector();
	private Vector nTabList = new Vector();
	private JFrame f;
	
	public static void main(String[] args) {
		new NIAM();
	}
	
	public NIAM() {
	    // create frame
	    f = new JFrame("NIAM (N Is After M)");
	    //f.setSize(400, 400);
	    Box mainBox = new Box(BoxLayout.Y_AXIS);
	    
	    // set upper area GUI
	    Box topBox = new Box( BoxLayout.X_AXIS);
	    mainBox.add(topBox);
	    Box makeBox = new Box( BoxLayout.Y_AXIS);
	    JPanel composePanel = new JPanel();
	    composeButton = new Button("Compose");
	    composeButton.addActionListener(this);
	    composePanel.add(composeButton);
	    makeBox.add( composePanel);
	    JPanel savePanel = new JPanel();
	    saveButton = new Button("Save");
	    saveButton.addActionListener(this);
	    savePanel.add(saveButton);
	    makeBox.add(savePanel);
	    topBox.add( makeBox);
	    
	    topBox.add(new QTPanel(new QTUtil(), score));
	    JPanel newPartPanel = new JPanel();
	    newPartButton = new Button("New part");
	    newPartButton.addActionListener(this);
	    newPartPanel.add(newPartButton);
	    JPanel deletePartPanel = new JPanel();
	    deletePartButton = new Button("Delete part");
	    deletePartButton.addActionListener(this);
	    deletePartPanel.add(deletePartButton);
	    Box partControlBox = new Box( BoxLayout.Y_AXIS);
	    partControlBox.add(newPartPanel);
	    partControlBox.add(deletePartPanel);
	    JPanel authorPanel = new JPanel();
	    authorPanel.add( new JLabel(" Andrew R. Brown"));
	    partControlBox.add( authorPanel);
	    topBox.add( partControlBox);
	    
	    tabPane = new JTabbedPane();
	    //JPanel part1Panel = new JPanel();
	    //tabPane.addTab("Part 1", part1Panel);
	    
	    mainBox.add(tabPane);
	    
	    f.getContentPane().add(mainBox);
	    
	    
	    // create a new part for N
	    for(int i=0; i<1;i++) {
	       addPart();
        }
        f.pack();
        f.setVisible(true);
	    
	    //Write.midi(score);
	    
	    // make score and play
	    //QTPlayer.display(score);
	    
	    // display
	    //View.print(score);
	}
	
	private void addPart() {
	    // don't exceed MIDi channel limit
	    if (score.size() >= 16) return;
	    NPart np = new NPart(newPart());
	    nPartList.addElement(np);
	    np.composePart( (NTabPanel)nTabList.elementAt(nTabList.size()-1));
	    f.pack();
	}
	
	private Part newPart() {
	    Part p = new Part();
	    p.setChannel(score.size());
	    score.addPart(p);
	    // deal with GUI
	    NTabPanel ntp = new NTabPanel(p);
	    tabPane.addTab("Part " + score.size(), ntp);
	    tabPane.setSelectedIndex(tabPane.getTabCount() - 1);
	    nTabList.addElement(ntp);
	    
	    return p;
	}
	
	public void actionPerformed(ActionEvent e) {
	    if(e.getSource() == composeButton) {
	        composeButton.setEnabled(false);
	        for(int i=0;i<nPartList.size();i++) {
	            ((NPart)nPartList.elementAt(i)).composePart((NTabPanel)nTabList.elementAt(i));
	        }
	        composeButton.setEnabled(true);
	    }
	    if(e.getSource() == saveButton) {
	        saveButton.setEnabled(false); 
	        Write.midi(score, "N.mid");
	        saveButton.setEnabled(true);
	    }
	    if(e.getSource() == newPartButton) addPart();
	    if(e.getSource() == deletePartButton) {
	        int lastPart = nTabList.size() -1;
	        if (lastPart < 1) return;
	        tabPane.remove((NTabPanel)nTabList.elementAt(lastPart));
	        tabPane.repaint();
	        nPartList.removeElementAt(lastPart);
	        nTabList.removeElementAt(lastPart);
	        score.removePart(lastPart);
	    }
	}
	
	
}
