/*

 Copyright (C) 2002 Andrew Brown

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or any
 later version.

 This program is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */

import jm.JMC;
import jm.music.data.*;
import jm.util.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;

/**
* This class is aprt of the interface for the NAIM program.
*
* @author Andrew Brown
*/

public class NTabPanel extends JPanel implements JMC {;
	private Part part;
	public JTextField instrumentValue, pitchValues, startTimeValue, 
	        lengthValue, fadeInValue, fadeOutValue, rhythmValues, dynamicValues,
	        panValues, durationValues;
	public ButtonGroup pitchOrderGroup, rhythmOrderGroup, dynamicOrderGroup,
	        panOrderGroup, durationOrderGroup;
	
	public NTabPanel(Part p) {
	    super();
	    this.part = p;
	    Box partBox = new Box(BoxLayout.Y_AXIS);
	    this.add(partBox);
	    // obverall settings
	    JPanel overallPanel = new JPanel();
	    JLabel instrumentLabel = new JLabel("Instrument:");
	    overallPanel.add(instrumentLabel);
	    instrumentValue = new JTextField("0", 4);
	    overallPanel.add(instrumentValue);
	    JLabel startTimeLabel = new JLabel("Start Time:");
	    overallPanel.add(startTimeLabel);
	    startTimeValue = new JTextField("0.0", 4);
	    overallPanel.add(startTimeValue);
	    JLabel lengthLabel = new JLabel("Length:");
	    overallPanel.add( lengthLabel);
	    lengthValue= new JTextField("36.0", 4);
	    overallPanel.add( lengthValue);
	    JPanel fadePanel = new JPanel();
	    JLabel fadeInLabel = new JLabel("Fade in length:");
	    partBox.add(overallPanel);
	     // fades
	    fadeInValue = new JTextField("4.0", 4);
	    fadePanel.add(fadeInLabel);
	    fadePanel.add(fadeInValue);
	    JLabel fadeOutLabel = new JLabel("Fade out length:");
	    fadeOutValue = new JTextField("12.0", 4);
	    fadePanel.add(fadeOutLabel);
	    fadePanel.add(fadeOutValue);
	    partBox.add(fadePanel);
	    // pitches
	    JPanel pitchPanel = new JPanel();
	    pitchPanel.setLayout(new GridLayout(2,1));
	    JPanel pitchValuesPanel = new JPanel();
	    JLabel pitchTitle = new JLabel("Pitch Values:");
	    pitchValuesPanel.add(pitchTitle);
	    pitchValues = new JTextField("60", 29);
	    pitchValuesPanel.add(pitchValues);
	    pitchPanel.add( pitchValuesPanel);
	    
	    // pitch order
	    JPanel pitchOrderPanel = new JPanel();
        pitchOrderGroup = new ButtonGroup();
        
        JLabel pitchOrderLabel = new JLabel("Pitch Order:");
        pitchOrderPanel.add( pitchOrderLabel);
        
        JRadioButton radioButton;
        pitchOrderPanel.add(radioButton = new JRadioButton("Original", true));
        radioButton.setActionCommand("Original");
        pitchOrderGroup.add(radioButton);
        
        pitchOrderPanel.add(radioButton = new JRadioButton("Random Loop"));
        radioButton.setActionCommand("RandomLoop");
        pitchOrderGroup.add(radioButton);
        
        pitchOrderPanel.add(radioButton = new JRadioButton("All Random"));
        radioButton.setActionCommand("AllRandom");
        pitchOrderGroup.add(radioButton);
        
        pitchPanel.add( pitchOrderPanel);
        
        // set border and add
        pitchPanel.setBorder(BorderFactory.createTitledBorder("Pitch"));
        partBox.add(pitchPanel);
        
        // rhythms
	    JPanel rhythmPanel = new JPanel();
	    rhythmPanel.setLayout(new GridLayout(2,1));
	    JPanel rhythmValuesPanel = new JPanel();
	    JLabel rhythmTitle = new JLabel("Rhythm Values:");
	    rhythmValuesPanel.add(rhythmTitle);
	    rhythmValues = new JTextField("1.0", 29);
	    rhythmValuesPanel.add(rhythmValues);
	    rhythmPanel.add( rhythmValuesPanel);
	    
	    // rhythm order
	    JPanel rhythmOrderPanel = new JPanel();
        rhythmOrderGroup = new ButtonGroup();
        
        JLabel rhythmOrderLabel = new JLabel("Rhythm Order:");
        rhythmOrderPanel.add( rhythmOrderLabel);
        
        rhythmOrderPanel.add(radioButton = new JRadioButton("Original", true));
        radioButton.setActionCommand("Original");
        rhythmOrderGroup.add(radioButton);
        
        rhythmOrderPanel.add(radioButton = new JRadioButton("Random Loop"));
        radioButton.setActionCommand("RandomLoop");
        rhythmOrderGroup.add(radioButton);
        
        rhythmOrderPanel.add(radioButton = new JRadioButton("All Random"));
        radioButton.setActionCommand("AllRandom");
        rhythmOrderGroup.add(radioButton);
        
        rhythmPanel.add( rhythmOrderPanel);
        
        // set border and add
        rhythmPanel.setBorder(BorderFactory.createTitledBorder("Rhythm"));
	    partBox.add(rhythmPanel);
	    
	    // Dynamic
	    JPanel dynamicPanel = new JPanel();
	    dynamicPanel.setLayout(new GridLayout(2,1));
	    JPanel dynamicValuesPanel = new JPanel();
	    JLabel dynamicTitle = new JLabel("Dynamic Values:");
	    dynamicValuesPanel.add(dynamicTitle);
	    dynamicValues = new JTextField("100", 29);
	    dynamicValuesPanel.add(dynamicValues);
	    dynamicPanel.add( dynamicValuesPanel);
	    
	    // dynamic order
	    JPanel dynamicOrderPanel = new JPanel();
        dynamicOrderGroup = new ButtonGroup();
        
        JLabel dynamicOrderLabel = new JLabel("Dynamic Order:");
        dynamicOrderPanel.add( dynamicOrderLabel);
        
        dynamicOrderPanel.add(radioButton = new JRadioButton("Original", true));
        radioButton.setActionCommand("Original");
        dynamicOrderGroup.add(radioButton);
        
        dynamicOrderPanel.add(radioButton = new JRadioButton("Random Loop"));
        radioButton.setActionCommand("RandomLoop");
        dynamicOrderGroup.add(radioButton);
        
        dynamicOrderPanel.add(radioButton = new JRadioButton("All Random"));
        radioButton.setActionCommand("AllRandom");
        dynamicOrderGroup.add(radioButton);
        
        dynamicPanel.add( dynamicOrderPanel);
        
        // set border and add
        dynamicPanel.setBorder(BorderFactory.createTitledBorder("Dynamic"));
	    partBox.add(dynamicPanel);
	    
	    // pans
	    JPanel panPanel = new JPanel();
	    panPanel.setLayout(new GridLayout(2,1));
	    JPanel panValuesPanel = new JPanel();
	    JLabel panTitle = new JLabel("Pan Values:");
	    panValuesPanel.add(panTitle);
	    panValues = new JTextField("0.5", 29);
	    panValuesPanel.add(panValues);
	    panPanel.add( panValuesPanel);
	    
	    /* pan order
	    JPanel panOrderPanel = new JPanel();
        panOrderGroup = new ButtonGroup();
        
        JLabel panOrderLabel = new JLabel("Pan Order:");
        panOrderPanel.add( panOrderLabel);
        
        panOrderPanel.add(radioButton = new JRadioButton("Original", true));
        radioButton.setActionCommand("Original");
        panOrderGroup.add(radioButton);
        
        panOrderPanel.add(radioButton = new JRadioButton("Random Loop"));
        radioButton.setActionCommand("RandomLoop");
        panOrderGroup.add(radioButton);
        
        panOrderPanel.add(radioButton = new JRadioButton("All Random"));
        radioButton.setActionCommand("AllRandom");
        panOrderGroup.add(radioButton);
        
        panPanel.add( panOrderPanel);
        
        // set border and add
        panPanel.setBorder(BorderFactory.createTitledBorder("Pan"));
	    partBox.add(panPanel);
	    
	    */
	    
	    // durations
	    JPanel durationPanel = new JPanel();
	    durationPanel.setLayout(new GridLayout(2,1));
	    JPanel durationValuesPanel = new JPanel();
	    JLabel durationTitle = new JLabel("Duration Values:");
	    durationValuesPanel.add(durationTitle);
	    durationValues = new JTextField("0.9", 29);
	    durationValuesPanel.add(durationValues);
	    durationPanel.add( durationValuesPanel);
	    
	    // duration order
	    JPanel durationOrderPanel = new JPanel();
        durationOrderGroup = new ButtonGroup();
        
        JLabel durationOrderLabel = new JLabel("Duration Order:");
        durationOrderPanel.add( durationOrderLabel);
        
        durationOrderPanel.add(radioButton = new JRadioButton("Original", true));
        radioButton.setActionCommand("Original");
        durationOrderGroup.add(radioButton);
        
        durationOrderPanel.add(radioButton = new JRadioButton("Random Loop"));
        radioButton.setActionCommand("RandomLoop");
        durationOrderGroup.add(radioButton);
        
        durationOrderPanel.add(radioButton = new JRadioButton("All Random"));
        radioButton.setActionCommand("AllRandom");
        durationOrderGroup.add(radioButton);
        
        durationPanel.add( durationOrderPanel);
        
        // set border and add
        durationPanel.setBorder(BorderFactory.createTitledBorder("Duration"));
	    partBox.add(durationPanel);
    }
	
}
